==> pipewire-docs-1%3A1.4.10-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/page_internals.js <==
var page_internals =
[
    [ "Design", "page_design.html", null ],
    [ "Audio", "page_audio.html", null ],
    [ "Access Control", "page_access.html", null ],
    [ "Portal Access Control", "page_portal.html", null ],
    [ "MIDI Support", "page_midi.html", null ],
    [ "Objects Design", "page_objects_design.html", null ],
    [ "PipeWire Library", "page_library.html", null ],
    [ "DMA-BUF Sharing", "page_dma_buf.html", null ],
    [ "Graph Scheduling", "page_scheduling.html", null ],
    [ "Native Protocol", "page_native_protocol.html", [
      [ "Message header", "page_native_protocol.html#native-protocol-message-header", null ],
      [ "Making a connection", "page_native_protocol.html#native-protocol-making-connection", null ],
      [ "Core proxy/resource", "page_native_protocol.html#native-protocol-core", null ],
      [ "Registry proxy/resource", "page_native_protocol.html#native-protocol-registry", null ],
      [ "PipeWire:Interface:Client", "page_native_protocol.html#native-protocol-client", null ],
      [ "PipeWire:Interface:Device", "page_native_protocol.html#native-protocol-device", null ],
      [ "PipeWire:Interface:Factory", "page_native_protocol.html#native-protocol-factory", null ],
      [ "PipeWire:Interface:Link", "page_native_protocol.html#native-protocol-link", null ],
      [ "PipeWire:Interface:Module", "page_native_protocol.html#native-protocol-module", null ],
      [ "PipeWire:Interface:Node", "page_native_protocol.html#native-protocol-node", null ],
      [ "PipeWire:Interface:Port", "page_native_protocol.html#native-protocol-port", null ],
      [ "PipeWire:Interface:ClientNode", "page_native_protocol.html#native-protocol-clientnode", null ],
      [ "PipeWire:Interface:Metadata", "page_native_protocol.html#native-protocol-metadata", null ],
      [ "PipeWire:Interface:Profiler", "page_native_protocol.html#native-protocol-profiler", null ],
      [ "Footer", "page_native_protocol.html#native-protocol-footer", null ],
      [ "Registry generation", "page_native_protocol.html#native-protocol-registry-generation", null ]
    ] ],
    [ "PipeWire Daemon", "page_daemon.html", null ],
    [ "PipeWire Session Manager", "page_session_manager.html", null ],
    [ "PulseAudio Compatibility", "page_pulseaudio.html", null ]
];

==> pipewire-docs-1%3A1.6.0-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/page_internals.js <==
var page_internals =
[
    [ "Design", "page_design.html", null ],
    [ "Audio", "page_audio.html", null ],
    [ "Access Control", "page_access.html", null ],
    [ "Portal Access Control", "page_portal.html", null ],
    [ "MIDI Support", "page_midi.html", null ],
    [ "Objects Design", "page_objects_design.html", null ],
    [ "PipeWire Library", "page_library.html", null ],
    [ "DMA-BUF Sharing", "page_dma_buf.html", null ],
    [ "Graph Scheduling", "page_scheduling.html", null ],
    [ "Driver architecture and workflow", "page_driver.html", null ],
    [ "Latency support", "page_latency.html", null ],
    [ "Tag support", "page_tag.html", null ],
    [ "Native Protocol", "page_native_protocol.html", [
      [ "Message header", "page_native_protocol.html#native-protocol-message-header", null ],
      [ "Making a connection", "page_native_protocol.html#native-protocol-making-connection", null ],
      [ "Core proxy/resource", "page_native_protocol.html#native-protocol-core", null ],
      [ "Registry proxy/resource", "page_native_protocol.html#native-protocol-registry", null ],
      [ "PipeWire:Interface:Client", "page_native_protocol.html#native-protocol-client", null ],
      [ "PipeWire:Interface:Device", "page_native_protocol.html#native-protocol-device", null ],
      [ "PipeWire:Interface:Factory", "page_native_protocol.html#native-protocol-factory", null ],
      [ "PipeWire:Interface:Link", "page_native_protocol.html#native-protocol-link", null ],
      [ "PipeWire:Interface:Module", "page_native_protocol.html#native-protocol-module", null ],
      [ "PipeWire:Interface:Node", "page_native_protocol.html#native-protocol-node", null ],
      [ "PipeWire:Interface:Port", "page_native_protocol.html#native-protocol-port", null ],
      [ "PipeWire:Interface:ClientNode", "page_native_protocol.html#native-protocol-clientnode", null ],
      [ "PipeWire:Interface:Metadata", "page_native_protocol.html#native-protocol-metadata", null ],
      [ "PipeWire:Interface:Profiler", "page_native_protocol.html#native-protocol-profiler", null ],
      [ "Footer", "page_native_protocol.html#native-protocol-footer", null ],
      [ "Registry generation", "page_native_protocol.html#native-protocol-registry-generation", null ]
    ] ],
    [ "PipeWire Daemon", "page_daemon.html", null ],
    [ "PipeWire Session Manager", "page_session_manager.html", null ],
    [ "PulseAudio Compatibility", "page_pulseaudio.html", null ]
];
